@@ -3,7 +3,7 @@
  *  Module    : nntplib.c
  *  Author    : S. Barber & I. Lea
  *  Created   : 1991-01-12
- *  Updated   : 1999-11-29
+ *  Updated   : 1997-12-22
  *  Notes     : NNTP client routines taken from clientlib.c 1.5.11 (1991-02-10)
  *  Copyright : (c) Copyright 1991-99 by Stan Barber & Iain Lea
  *              Permission is hereby granted to copy, reproduce, redistribute
@@ -578,12 +578,14 @@ get_tcp6_socket (
 	struct addrinfo hints, *res, *res0;
 
 #	if 0 /* currently we don't know if we have snprintf */
-	snprintf(mymachine, sizeof(mymachine), "%s", machine);
-	snprintf(myport, sizeof(myport), "%d", port);
+	snprintf(mymachine, sizeof(mymachine)-1, "%s", machine);
+	snprintf(myport, sizeof(myport)-1, "%d", port);
 #	else
-	my_strncpy(mymachine, machine, sizeof(mymachine));
+	my_strncpy(mymachine, machine, sizeof(mymachine)-1);
 	sprintf(myport, "%d", port);
 #	endif /* 0 */
+	mymachine[sizeof(mymachine)-1] = '\0';
+	myport[sizeof(myport)-1] = '\0';
 
 /* just in case */
 #	ifdef AF_UNSPEC
@@ -599,6 +601,7 @@ get_tcp6_socket (
 /*	hints.ai_flags    = AI_CANONNAME; */
 	hints.ai_family   = ADDRFAM;
 	hints.ai_socktype = SOCK_STREAM;
+	res = res0 = NULL;
 	err = getaddrinfo(mymachine, myport, &hints, &res0);
 	if (err != 0) {
 		my_fprintf (stderr, "\ngetaddrinfo: %s\n", gai_strerror(err)); /* FIXME: -> lang.c */
@@ -615,6 +618,7 @@ get_tcp6_socket (
 			break;
 		}
 	}
+	if (res0) freeaddrinfo(res0);
 	if (err < 0) {
 		my_fprintf (stderr, "\nsocket or connect problem\n"); /* FIXME: -> lang.c */
 		return (-1);
@@ -833,8 +837,25 @@ get_server (
 		if (errno != 0 && errno != EINTR)	/*	I'm sure this will only confuse end users*/
 			perror_message("get_server()");
 #		endif /* DEBUG */
-		retry = reconnect(retry);			/* Will abort when out of tries */
-		reconnected_in_last_get_server = TRUE;
+
+		/*
+		 * Reconnect only if command was not "QUIT" anyway (in which case a
+		 * reconnection would be useless because the connection will be
+		 * closed immediately). Also prevents tin from asking to reconnect
+		 * when user is quitting tin if tinrc.auto_reconnect is false.
+		 */
+		if (strncmp(last_put, "QUIT", 4)) {
+			retry = reconnect(retry);			/* Will abort when out of tries */
+			reconnected_in_last_get_server = TRUE;
+		} else {
+			/*
+			 * Use standard NNTP closing message and response code if user is
+			 * quitting tin and leave loop.
+			 */
+			strncpy(string, txt_nntp_ok_goodbye, size - 2);
+			strcat(string, cCRLF);	/* tin_fgets() needs CRLF */
+			break;
+		}
 	}
 
 	return string;
@@ -943,9 +964,6 @@ nntp_respcode (
 		case OK_POSTED:
 			text = "240  Article posted successfully";
 			break;
-	        case OK_AUTHSIMPLE:
-	     	        text = "250  Authorization accepted";
-                        break;
 		case OK_AUTHSYS:
 			text = "280  Authorization system ok";
 			break;
@@ -979,9 +997,6 @@ nntp_respcode (
 		case CONT_POST:
 			text = "340  Continue to post article";
 			break;
-	        case CONT_AUTHSIMPLE:
-		        text = "350  Continue with authorization sequence";
-			break;
 		case NEED_AUTHINFO:
 			text = "380  authorization is required";
 			break;
@@ -1030,12 +1045,6 @@ nntp_respcode (
 		case ERR_POSTFAIL:
 			text = "441  Posting failed";
 			break;
-	        case ERR_NOAUTHSIMPLE:
-	                text = "450  Authorization required for this command";
-	                break;
-	        case ERR_AUTHREJSIMPLE:
-	                text = "452  Authorization rejected";
-	                break;
 		case ERR_NOAUTH:
 			text = "480  authorization required for command";
 			break;
