@@ -1235,7 +1235,7 @@ subscribe_pattern (
 			if (match_group_list (active[i].name, buf)) {
 				if (active[i].subscribed != (state != FALSE)) {
 					spin_cursor ();
-					/* If found and group is not subscribed add it to end of my_group[]. */
+					/* If found and group is not subscribed add it to end of my_group[] */
 					subscribe (&active[i], SUB_CHAR(state));
 					if (state) {
 						my_group_add (active[i].name);
@@ -1459,7 +1459,7 @@ static void
 move_to_group (
 	int n)
 {
-	if (cur_groupnum == n)
+	if (cur_groupnum && cur_groupnum == n)
 		return;
 
 	HpGlitch(erase_group_arrow ());
